@@ -57,11 +57,20 @@ class Eaasy: # pragma: no cover
         # Create Flask app and API
         self._app = Flask(name)
         self._app.config.update(config)
+
+        methods = kwargs.get('methods', ['GET', 'POST', 'PUT', 'DELETE', 'OPTIONS'])
+        allow_headers = kwargs.get('allow_headers', ['Content-Type', 'Authorization'])
+        expose_headers = kwargs.get('expose_headers', ["Content-Disposition"])
+        resources = kwargs.get('resources', {r"/*": {"origins": "*"}})
+        supports_credentials = kwargs.get('supports_credentials', True)
+
         CORS(
             self._app,
-            methods=['GET', 'POST', 'PUT', 'DELETE', 'OPTIONS'],
-            resources={r"/*": {"origins": "*"}},
-            supports_credentials=True)
+            methods=methods,
+            allow_headers=allow_headers,
+            expose_headers=expose_headers,
+            resources=resources,
+            supports_credentials=supports_credentials)
         self._app.before_request(self.__before_request)
         self._api = Api( self._app, version=version, title=title, description=description, doc=doc, authorizations=authorizations, security=security)
         self._api.add_namespace(liveness_ns)
