@@ -201,4 +201,4 @@ def build_resource(
 
     if len(by_id) > 0:
         DynamicResourceById = build_dynamic_class('DynamicResourceById', by_id)
-        namespace.add_resource(DynamicResourceById, '/<int:id>')
+        namespace.add_resource(DynamicResourceById, '/<int:id>/')
