@@ -215,7 +215,7 @@ class TestBuilder(TestCase):
         build_resource(test_class, namespace, model, model)
         
         # Assert
-        found_resource = [x for x in namespace.resources if x.urls[0] == "/<int:id>"]
+        found_resource = [x for x in namespace.resources if x.urls[0] == "/<int:id>/"]
         self.assertEqual(1, len(found_resource))
 
     def test_building_resource_with_wrapper_applies_wrapper_to_methods(self, *_):
@@ -228,7 +228,7 @@ class TestBuilder(TestCase):
         
         # Assert
         get_all_resource = [x for x in namespace.resources if x.urls[0] == "/"][0]
-        get_by_id_resource = [x for x in namespace.resources if x.urls[0] == "/<int:id>"][0]
+        get_by_id_resource = [x for x in namespace.resources if x.urls[0] == "/<int:id>/"][0]
         self.assertTrue(hasattr(get_all_resource.resource, "get"))
         self.assertTrue(hasattr(get_by_id_resource.resource, "get"))
         self.assertTrue(callable(get_all_resource.resource.get))
@@ -360,7 +360,7 @@ class TestBuilder(TestCase):
 
         # Act
         with app.test_client() as client:
-            response = client.get(f'/{ns_name}/1')
+            response = client.get(f'/{ns_name}/1/')
 
         # Assert
         self.assertEqual(1, mock_entity.get_by_id.call_count)
@@ -379,7 +379,7 @@ class TestBuilder(TestCase):
 
         # Act
         with app.test_client() as client:
-            response = client.get(f'/{ns_name}/1')
+            response = client.get(f'/{ns_name}/1/')
 
         # Assert
         self.assertEqual(1, mock_entity.get_by_id.call_count)
@@ -407,7 +407,7 @@ class TestBuilder(TestCase):
 
         # Act
         with app.test_client() as client:
-            response = client.put(f'/{ns_name}/1', headers=headers, json={'test_prop': 'test_value'})
+            response = client.put(f'/{ns_name}/1/', headers=headers, json={'test_prop': 'test_value'})
 
         # Assert
         self.assertEqual(1, mock_entity.update.call_count)
@@ -427,7 +427,7 @@ class TestBuilder(TestCase):
 
         # Act
         with app.test_client() as client:
-            response = client.put(f'/{ns_name}/1', headers=headers, json={})
+            response = client.put(f'/{ns_name}/1/', headers=headers, json={})
 
         # Assert
         self.assertEqual(1, mock_entity.update.call_count)
@@ -441,7 +441,7 @@ class TestBuilder(TestCase):
         
         # Act
         with app.test_client() as client:
-            response = client.delete(f'/{ns_name}/1')
+            response = client.delete(f'/{ns_name}/1/')
 
         # Assert
         self.assertEqual(404, response.status_code)
@@ -454,7 +454,7 @@ class TestBuilder(TestCase):
 
         # Act
         with app.test_client() as client:
-            response = client.delete(f'/{ns_name}/1')
+            response = client.delete(f'/{ns_name}/1/')
 
         # Assert
         self.assertEqual(1, mock_entity.delete.call_count)
@@ -473,7 +473,7 @@ class TestBuilder(TestCase):
 
         # Act
         with app.test_client() as client:
-            response = client.delete(f'/{ns_name}/1')
+            response = client.delete(f'/{ns_name}/1/')
 
         # Assert
         self.assertEqual(1, mock_entity.delete.call_count)
@@ -507,7 +507,7 @@ class TestBuilder(TestCase):
 
         # Act
         with app.test_client() as client:
-            response = client.put(f'/{ns_name}/1', headers=headers, json={'test_prop': 'test_value'})
+            response = client.put(f'/{ns_name}/1/', headers=headers, json={'test_prop': 'test_value'})
 
         # Assert
         self.assertEqual(1, mock_entity.update.call_count)
@@ -523,7 +523,7 @@ class TestBuilder(TestCase):
 
         # Act
         with app.test_client() as client:
-            response = client.delete(f'/{ns_name}/1')
+            response = client.delete(f'/{ns_name}/1/')
 
         # Assert
         self.assertEqual(1, mock_entity.delete.call_count)
